@@ -46,14 +46,12 @@ class AbstractRunner(ABC):
 
 
     @abstractmethod
-    def runTrial(self,saver,  seed,  n, s, s_eval, n_fft, n_wavelet, add_wavelet_detail, calibration_step,  optimize_threshold, signal_type, idios_string):
+    def runTrial(self,saver,  seed,  n, s, s_eval, calibration_step, signal_type, idios_string):
         pass
 
 class ForecasterRunner(AbstractRunner):
-    def runTrial(self, saver, seed, n, s, s_eval, calibration_step, optimize_threshold, signal_type, idios_string):
-
-
-        continuous_saving_key, two_states_saving_key, three_states_saving_key = saver.create_saving_key(seed, n, s, s_eval, calibration_step, optimize_threshold, signal_type, idios_string)
+    def runTrial(self, saver, seed, n, s, s_eval, calibration_step, signal_type, idios_string):
+        continuous_saving_key, two_states_saving_key, three_states_saving_key = saver.create_saving_key(seed, n, s, s_eval, calibration_step, signal_type, idios_string)
 
         check_run_existence, table_number = saver.checkRunExistence(continuous_saving_key)
         exhaustive_check_run_existence, exhaustive_table_number = saver.exhaustiveCheckRunExistence(continuous_saving_key)
