@@ -10,6 +10,7 @@ from napoleontoolbox.signal import signal_generator
 from napoleontoolbox.connector import napoleon_connector
 from napoleontoolbox.signal import signal_utility
 from napoleontoolbox.parallel_run import signal_result_analyzer
+from napoleontoolbox.parallel_run import launcher_utility
 import json
 
 from pathlib import Path
@@ -42,9 +43,7 @@ class AbstractRunner(ABC):
         self.saving_return_path = self.local_root_directory+self.underlying+self.freqly_return_pkl_filename_suffix
         self.recompute_all = recompute_all
         self.db_path_suffix = db_path_suffix
-        self.db_path_name = user+'_'+frequence  + '_' + underlying + '_' + starting_date.strftime(
-            '%d_%b_%Y') + '_' + running_date.strftime('%d_%b_%Y') + db_path_suffix
-
+        self.db_path_name = launcher_utility.get_database_name(user, frequence, underlying, algo, starting_date, running_date, db_path_suffix)
 
         if not self.recompute_all:
             saver = signal_result_analyzer.ParallelRunResultAnalyzer(drop_token=drop_token,
