@@ -26,11 +26,10 @@ def unjsonize_mapping_dataframe(mapping_df):
 
 class ParallelRunResultAnalyzer():
 
-    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_suffix = '_run.sqlite', max_table_number = 20):
+    def __init__(self,drop_token='', dropbox_backup=True, local_root_directory='../data',user='napoleon',  db_path_name = None, max_table_number = 20):
         self.local_root_directory = local_root_directory
         self.user = user
-        self.db_path_suffix = db_path_suffix
-        self.filename =  user + db_path_suffix
+        self.filename = db_path_name
         self.db_path = self.local_root_directory + self.filename
         self.dbx = dropbox_file_saver.NaPoleonDropboxConnector(drop_token=drop_token,dropbox_backup=dropbox_backup)
         self.max_table_number = max_table_number
